==> huaweicloudsdksdrs-3.0.71-py2.py3-none-any.whl: huaweicloudsdksdrs/v1/model/delete_failure_job_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteFailureJobRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'failure_job_id': 'str'
    }

    attribute_map = {
        'failure_job_id': 'failure_job_id'
    }

    def __init__(self, failure_job_id=None):
        """DeleteFailureJobRequest - a model defined in huaweicloud sdk"""
        
        

        self._failure_job_id = None
        self.discriminator = None

        self.failure_job_id = failure_job_id

    @property
    def failure_job_id(self):
        """Gets the failure_job_id of this DeleteFailureJobRequest.

        失败任务ID。

        :return: The failure_job_id of this DeleteFailureJobRequest.
        :rtype: str
        """
        return self._failure_job_id

    @failure_job_id.setter
    def failure_job_id(self, failure_job_id):
        """Sets the failure_job_id of this DeleteFailureJobRequest.

        失败任务ID。

        :param failure_job_id: The failure_job_id of this DeleteFailureJobRequest.
        :type: str
        """
        self._failure_job_id = failure_job_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteFailureJobRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdksdrs-3.0.100-py2.py3-none-any.whl: huaweicloudsdksdrs/v1/model/delete_failure_job_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteFailureJobRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'failure_job_id': 'str'
    }

    attribute_map = {
        'failure_job_id': 'failure_job_id'
    }

    def __init__(self, failure_job_id=None):
        """DeleteFailureJobRequest

        The model defined in huaweicloud sdk

        :param failure_job_id: 失败任务ID。
        :type failure_job_id: str
        """
        
        

        self._failure_job_id = None
        self.discriminator = None

        self.failure_job_id = failure_job_id

    @property
    def failure_job_id(self):
        """Gets the failure_job_id of this DeleteFailureJobRequest.

        失败任务ID。

        :return: The failure_job_id of this DeleteFailureJobRequest.
        :rtype: str
        """
        return self._failure_job_id

    @failure_job_id.setter
    def failure_job_id(self, failure_job_id):
        """Sets the failure_job_id of this DeleteFailureJobRequest.

        失败任务ID。

        :param failure_job_id: The failure_job_id of this DeleteFailureJobRequest.
        :type failure_job_id: str
        """
        self._failure_job_id = failure_job_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteFailureJobRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
